Stan Math Library: stan/math/rev/core/operator_unary_not.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

operator_unary_not.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_OPERATOR_UNARY_NOT_HPP
2 #define STAN_MATH_REV_CORE_OPERATOR_UNARY_NOT_HPP
3
4 #include <stan/math/rev/core/var.hpp>
5
6 namespace stan {
7 namespace math {
8
31 inline bool operator!(const var& a) {
32 return !a.val();
33 }
34
35 }
36 }
37 #endif
stan::math::operator!
bool operator!(const var &a)
Prefix logical negation for the value of variables (C++).
Definition: operator_unary_not.hpp:31
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
var.hpp
stan::math::var::val
double val() const
Return the value of this variable.
Definition: var.hpp:233

[ Stan Home Page ] © 2011–2016, Stan Development Team.